@@ -22,7 +22,7 @@ import prasopes.imagetools as imgt
 import prasopes.zcetools as zce
 import prasopes.docks as docks
 import prasopes.datasets as datasets
-import prasopes.mobtools as mt
+import prasopes.mobtools_gui as mtg
 import prasopes.tangoicons
 import sys
 import logging
@@ -222,7 +222,7 @@ def paint_override(self, augCanvas):
             for i, line in enumerate(data)]
     xtics = int(cf.settings().value(self.conftype.format("xtics")))
     self.plot.locator_params(nbins=xtics, axis='x')
-    if augCanvas.ds:
+    if augCanvas.ds and cf.settings().value("imggen/path", type=bool):
         self.plot.set_title(Path(
             *Path(augCanvas.ds.filename).resolve().parts[-2:]), loc="right")
 
@@ -350,7 +350,7 @@ def main():
     tofact = QtWidgets.QAction(QtGui.QIcon.fromTheme(
         "applications-utilities"), "&MOB...", None)
     tofact.setShortcut(QtCore.Qt.CTRL + QtCore.Qt.Key_M)
-    tofact.triggered.connect(lambda: mt.main_window(
+    tofact.triggered.connect(lambda: mtg.main_window(
         main_window, augCanvas, update))
     aboutact = QtWidgets.QAction("&About Prasopes", None)
     aboutact.triggered.connect(lambda: about(main_window))
