@@ -35,6 +35,7 @@ def settings():
                ("imggen/drlspec_xinch", 10),
                ("imggen/drlspec_yinch", 4),
                ("imggen/drlspec_dpi", 300),
+               ("imggen/path", True),
                ("imggen/reactspecspec_xinch", 3.5),
                ("imggen/reactspecspec_yinch", 2),
                ("imggen/reactspecspec_dpi", 300),
@@ -138,6 +139,8 @@ def dial(parent):
         "Figure x axis major ticks count", "imggen/msspec_xtics", config))
     imggenlayout.addWidget(checkboxconf(
         "Manual annotation only", "imggen/msspec_onlymanann", config))
+    imggenlayout.addWidget(checkboxconf(
+        "Isert path to exported image", "imggen/path", config))
     tabs.addTab(imggentab, "Image clip/export")
 
     timstoftab = QtWidgets.QWidget()
