@@ -44,7 +44,7 @@ def update_profile(pt, row, dataset):
     limits = []
     spectra = dataset.get_spectra(-np.inf, np.inf)
     for i, spectxy in enumerate(spectra):
-        massargs = drl.get_massargs(pt, row, spectxy[0])
+        massargs = drl.get_subargs(pt, row, spectxy[0], 1, 2)
         spectrum.plot(spectxy[0], spectxy[1], ':', color='gray')
         spectrum.plot(spectxy[0][massargs], spectxy[1][massargs],
                       color=gt.colors[i % len(gt.colors)]/255)
